<?php
/*
*
*	***** Evangelische Termine for The Events Calendar *****
*
*	YSPEECHETFTEC Import Functions
*	
*/
// If this file is called directly, abort. //
if (!defined('WPINC')) {
    die;
} // end if


define('YSPEECHTFTEC_ET_XML_BASE_URL', 'https://yspeech.de/wp-json/yeta/v1/import?');

/**
 * Import events
 * 
 */
function yspeechetftec_import_events()
{

    $yspeechetftec_import_options = get_option('yspeechetftec_import');
    $yspeechetftec_license_options = get_option('yspeechetftec_license');


    $uri_params = '';

    if (isset($yspeechetftec_import_options['yspeechetftec_organizer_ids']) && strlen(trim($yspeechetftec_import_options['yspeechetftec_organizer_ids'])) > 0) {

        $uri_params = $uri_params . 'vids=' . $yspeechetftec_import_options['yspeechetftec_organizer_ids'];
    }
    if (isset($yspeechetftec_import_options['yspeechetftec_region_ids']) && strlen(trim($yspeechetftec_import_options['yspeechetftec_region_ids'])) > 0) {
        if (strlen($uri_params) > 0) {
            $uri_params = $uri_params . '&';
        }
        $uri_params = $uri_params . 'regions=' . $yspeechetftec_import_options['yspeechetftec_region_ids'];
    }


    if (strlen($uri_params) > 0) {

        try {
            if (isset($yspeechetftec_license_options['yspeechetftec_license_key']) && strlen(trim($yspeechetftec_license_options['yspeechetftec_license_key'])) > 0) {
                $uri_params = $uri_params . '&license=' . $yspeechetftec_license_options['yspeechetftec_license_key'];
            }

            $response = wp_remote_get(
                YSPEECHTFTEC_ET_XML_BASE_URL  . $uri_params
                    . '&X-API-Key=' . YSPEECHETFTEC_YSPEECH_LICENSE_API_APPLICATION_AUTH,
                array(
                    'timeout' => 30,
                    'redirection' => 10,
                    'method' => 'GET',
                    'httpversion' => 1.1,
                    'headers' => array(
                        'Content-Type'  => 'application/json',
                    )
                )
            );

            $events = json_decode(wp_remote_retrieve_body($response));
            $response_code = wp_remote_retrieve_response_code($response);
            if ($response_code === 200) {

                yspeechetftec_import_events_remove_deleted($events);

                foreach ($events as $event) {
                    $event->post_author = $yspeechetftec_import_options['yspeechetftec_publisher_id'];

                    $categories = explode(', ', (string) $event->categories);

                    $hierarchicalTerms = array();
                    foreach ($categories as $cat) {
                        $cat = trim($cat);
                        if (strlen($cat) >= 2) {
                            $term = term_exists($cat, Tribe__Events__Main::TAXONOMY);
                            if ($term === null) {
                                $term = wp_insert_term($cat, Tribe__Events__Main::TAXONOMY);
                            }
                            array_push($hierarchicalTerms, $term['term_id']);
                        }
                    }

                    if (isset($event->Organizer)) {
                        $rd_args = array(
                            'post_type' => 'tribe_organizer',
                            'numberposts' => -1,
                            'title' => (string) $event->Organizer->Organizer,
                        );

                        $rd_query = get_posts($rd_args);

                        if (count($rd_query) === 1) {
                            $event->Organizer->OrganizerID = $rd_query[0]->ID;
                        }
                    }

                    $event->tax_input = array(Tribe__Events__Main::TAXONOMY => $hierarchicalTerms);
                    $event = json_decode(json_encode($event), true);
                    // Save or update event
                    try {
                        if (tribe_post_exists($event['import_id'])) {
                            tribe_update_event($event['import_id'], $event);
                        } else {
                            tribe_create_event($event);
                        }
                    } catch (Exception $e) {
                        echo (esc_html("<hr>Error #:" . $e));
                    }
                }
            }
        } catch (Exception $e) {
            echo (esc_html("<hr>cURL Error #:" . $e));
        }
    }

    if (is_admin()) {
        wp_safe_redirect(get_admin_url() . 'admin.php?page=yspeechetftec-ev-termine');
        exit;
    }
}

function yspeechetftec_mapImportIds($e)
{
    return $e->import_id;
}

function yspeechetftec_import_events_remove_deleted($events)
{
    $importedEventIds = array_map('yspeechetftec_mapImportIds', $events);

    $tribeEventFilter = array(
        'post_type' => 'tribe_events',
        'order' => 'ASC',
        'tribe_suppress_query_filters' => 1,
        'meta_key' => 'et_id',
        'meta_query' => array(
            'relation' => 'AND',
            '_eventhidefromupcoming_not_exists' => array(
                'key' => '_EventHideFromUpcoming',
                'compare' => 'NOT EXISTS'
            ),

            'starts-after' => array(
                'key' => '_EventStartDate',
                'compare' => '>=',
                'value' => (new DateTime())->format('Y-m-d'),
                'type' => 'DATETIME'
            ),
            '_not_in_import' => array(
                'key' => 'et_id',
                'compare' => 'NOT IN',
                'value' => $importedEventIds
            )
        ),
        'tax_query' => array(
            'relation' => 'AND'
        ),

        'date_query' => array(
            'relation' => 'AND'
        ),

        'eventDisplay' => 'custom',
        'posts_per_page' => -1,
        'tribe_render_context' => 'default',
        'post_status' => array(
            'publish',
            'private'
        ),
        'fields' => 'ids'
    );

    $allFutureTribeEvents = new WP_Query($tribeEventFilter);

    foreach ($allFutureTribeEvents->posts as $id) {
        tribe_delete_event($id, true);
    }
}
