<?php
/*
*
*	***** Evangelische Termine for The Events Calendar *****
*
*	YSPEECHETFTEC Views Functions
*	
*/
// If this file is called directly, abort. //
if (!defined('WPINC')) {
    die;
} // end if


if (class_exists('Tribe__Events__Main')) {

    /**
     * Event Feedback Link (more info)
     *
     * @param null|object|int $event
     * @param null|string     $label
     *
     * @return string $html
     */
    function yspeechetftec_get_event_feedback_link($event = null, $label = null)
    {
        // We won't get far without a post ID. Especially since we pass it to filters that depend on it.
        $post_id = Tribe__Events__Main::postIdHelper($event);
        $url     = yspeechetftec_get_event_feedback_url($post_id);

        /**
         * Filter the target attribute for the event feedback link
         *
         * @since 5.1.0
         * @since 5.5.0 Added $post_id argument
         *
         * @param string          $target The target attribute string. Defaults to "_self".
         * @param string          $url    The link URL.
         * @param null|object|int $post_id  The event the url is attached to.
         */
        $target = apply_filters('yspeechetftec_get_event_feedback_link_target', '_blank', $url, $post_id);
        $rel    = ('_blank' === $target) ? 'noopener noreferrer' : 'external';

        if (!empty($url)) {
            $label = is_null($label) ? $url : $label;
            /**
             * Filter the feedback link label
             *
             * @since 3.0
             *
             * @param string the link label/text.
             */
            $label = apply_filters('yspeechetftec_get_event_feedback_link_label', $label, $post_id);
            $html  = sprintf(
                '<a href="%s" target="%s" rel="%s">%s</a>',
                esc_url($url),
                esc_attr($target),
                esc_attr($rel),
                esc_html($label)
            );
        } else {
            $html = '';
        }

        /**
         * Filter the feedback link HTML
         *
         * @since 3.0
         *
         * @param string the link HTML.
         */
        return apply_filters('yspeechetftec_get_event_feedback_link', $html);
    }

    /**
     * Event Target Group (more info)
     *
     * @param null|object|int $event
     * @param null|string     $label
     *
     * @return string $html
     */
    function yspeechetftec_get_event_target_group($event = null, $label = null)
    {
        // We won't get far without a post ID. Especially since we pass it to filters that depend on it.
        $post_id = Tribe__Events__Main::postIdHelper($event);
        $target_group_data = yspeechetftec_get_event_target_group_data($post_id);
        $target_group = is_array($target_group_data) ? implode(', ', $target_group_data) : $target_group_data;



        if (!empty($target_group)) {
            $label = is_null($label) ? $target_group : $label;

            $html  = sprintf(
                '<div>%s</div>',
                esc_html($target_group),
            );
        } else {
            $html = '';
        }

        /**
         * Filter the target group HTML
         *
         * @since 3.0
         *
         * @param string the target group HTML.
         */
        return apply_filters('yspeechetftec_get_event_target_group', $html);
    }

    /**
     * Get the link for the event feedback.
     *
     * @since 5.5.0
     *
     * @param null|int $post_id The event or event ID.
     * @return string  Formatted title for the event feedback link
     */
    function yspeechetftec_get_event_feedback_link_title($post_id = null)
    {
        $post_id = Tribe__Events__Main::postIdHelper($post_id);;

        /**
         * Allows customization of a event's feedback title link.
         *
         * @since 5.5.0
         *
         * @param string $title The title of the event's feedback link.
         * @param int 	 $post_id The event ID.
         */
        return apply_filters('yspeechetftec_get_event_feedback_link_title', __('Anmeldung:', 'yspeechetftec'), $post_id);
    }

    /**
     * Get the target group title for the event.
     *
     * @since 5.5.0
     *
     * @param null|int $post_id The event or event ID.
     * @return string  Formatted title for the event target group
     */
    function yspeechetftec_get_event_target_group_title($post_id = null)
    {
        $post_id = Tribe__Events__Main::postIdHelper($post_id);;

        /**
         * Allows customization of a event's target group title.
         *
         * @since 5.5.0
         *
         * @param string $title The title of the event's tartget group.
         * @param int 	 $post_id The event ID.
         */
        return apply_filters('yspeechetftec_get_event_target_group_title', __('Zielgruppe:', 'yspeechetftec'), $post_id);
    }

    /**
     * Event Feedback URL
     *
     * @param null|object|int $event
     *
     * @return string The event's feedback URL
     */
    function yspeechetftec_get_event_feedback_url($event = null)
    {
        $post_id = (is_object($event) && isset($event->tribe_is_event) && $event->tribe_is_event) ? $event->ID : $event;
        $post_id = (!empty($post_id) || empty($GLOBALS['post'])) ? $post_id : get_the_ID();
        $url     = tribe_get_event_meta($post_id, 'et_event_FEEDBACK_ID', true);

        return apply_filters('yspeechetftec_get_event_feedback_url', $url, $post_id);
    }

    /**
     * Event Target Groups
     *
     * @param null|object|int $event
     *
     * @return string|array The event's target groups
     */
    function yspeechetftec_get_event_target_group_data($event = null)
    {
        $post_id = (is_object($event) && isset($event->tribe_is_event) && $event->tribe_is_event) ? $event->ID : $event;
        $post_id = (!empty($post_id) || empty($GLOBALS['post'])) ? $post_id : get_the_ID();
        $target_group = tribe_get_event_meta($post_id, 'et_event_PEOPLE', true);

        return apply_filters('yspeechetftec_get_event_target_group_data', $target_group, $post_id);
    }
}
